use anyhow::Result;

use ecs::*;
use engine::prelude::*;

use crate::game::{Game, InputSettings};

#[derive(Default, Resource)]
pub enum GameState {
    #[default]
    Startup,

    Game(Game),
}

impl GameState {
    pub fn update(commands: &mut Commands, game_state: &mut GameState) -> Result<bool> {
        match game_state {
            GameState::Startup => *game_state = GameState::Game(Game),
            GameState::Game(game) => game.update(commands)?,
        }

        Ok(true)
    }

    pub fn event(
        &mut self,
        commands: &mut Commands,
        event: EngineEvent<'_>,
        input_settings: &mut InputSettings,
    ) -> Result<()> {
        match self {
            GameState::Startup => (),
            GameState::Game(game) => game.event(commands, event, input_settings)?,
        }

        Ok(())
    }
}
